==> secbus-0.1.tgz: secbus-0.1/src/axi_vci/axi_vci_simi.tcl <==
#
# SecBus ( http://secbus.telecom-paristech.fr/ ) - This file is part of SecBus
# Copyright (C) 2009-2015 - Telecom ParisTech
# Contacts: contact-secbus@telecom-paristech.fr
#
# This file must be used under the terms of the CeCILL.
# This source file is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at
# http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
#

onerror {resume}
quietly WaveActivateNextPane {} 0
add wave -noupdate /axi_vci_sim/iaxi_ram/clk
add wave -noupdate /axi_vci_sim/iaxi_ram/srstn
add wave -noupdate /axi_vci_sim/iaxi_ram/ce
add wave -noupdate -divider axi_2vci
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/r_state
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/p_axi_in
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/p_axi_out
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/p_vci_out
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/p_vci_in
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/r_addr
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/r_plen
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/r_srcid
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/r_trdid
add wave -noupdate -divider vci_2axi
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_state
add wave -noupdate /axi_vci_sim/ivci_2_axi/p_axi_in
add wave -noupdate /axi_vci_sim/ivci_2_axi/p_axi_out
add wave -noupdate -childformat {{/axi_vci_sim/ivci_2_axi/p_vci_in.plen -radix decimal}} -subitemconfig {/axi_vci_sim/ivci_2_axi/p_vci_in.plen {-height 16 -radix decimal}} /axi_vci_sim/ivci_2_axi/p_vci_in
add wave -noupdate /axi_vci_sim/ivci_2_axi/p_vci_out
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_addr
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_len
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_burst
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_srcid
add wave -noupdate -divider axi_ram
add wave -noupdate /axi_vci_sim/iaxi_ram/r_state
add wave -noupdate /axi_vci_sim/iaxi_ram/p_axi_in
add wave -noupdate /axi_vci_sim/iaxi_ram/p_axi_out
add wave -noupdate /axi_vci_sim/iaxi_ram/r_words
add wave -noupdate /axi_vci_sim/iaxi_ram/r_cnt
add wave -noupdate /axi_vci_sim/iaxi_ram/r_addr
add wave -noupdate /axi_vci_sim/iaxi_ram/r_srcid
add wave -noupdate /axi_vci_sim/iaxi_ram/s_data_in
add wave -noupdate /axi_vci_sim/iaxi_ram/s_data_out
add wave -noupdate /axi_vci_sim/iaxi_ram/s_be_in
add wave -noupdate /axi_vci_sim/iaxi_ram/s_eop
add wave -noupdate /axi_vci_sim/iaxi_ram/s_wen
TreeUpdate [SetDefaultTree]
WaveRestoreCursors {{Cursor 1} {381000 ps} 0}
quietly wave cursor active 1
configure wave -namecolwidth 160
configure wave -valuecolwidth 100
configure wave -justifyvalue left
configure wave -signalnamewidth 1
configure wave -snapdistance 10
configure wave -datasetprefix 0
configure wave -rowmargin 4
configure wave -childrowmargin 2
configure wave -gridoffset 0
configure wave -gridperiod 1
configure wave -griddelta 40
configure wave -timeline 0
configure wave -timelineunits ps
update
WaveRestoreZoom {0 ps} {15898 ps}

==> secbus-0.2.1.tgz: secbus-0.2/src/axi_vci/axi_vci_simi.tcl <==
onerror {resume}
quietly WaveActivateNextPane {} 0
add wave -noupdate /axi_vci_sim/iaxi_ram/clk
add wave -noupdate /axi_vci_sim/iaxi_ram/srstn
add wave -noupdate /axi_vci_sim/iaxi_ram/ce
add wave -noupdate -divider axi_2vci
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/r_state
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/p_axi_in
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/p_axi_out
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/p_vci_out
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/p_vci_in
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/r_addr
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/r_srcid
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/s_eop
add wave -noupdate /axi_vci_sim/iaxi4_2_vci/s_last
add wave -noupdate -divider vci_2axi
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_state
add wave -noupdate /axi_vci_sim/ivci_2_axi/p_axi_in
add wave -noupdate /axi_vci_sim/ivci_2_axi/p_axi_out
add wave -noupdate -childformat {{/axi_vci_sim/ivci_2_axi/p_vci_in.plen -radix decimal}} -subitemconfig {/axi_vci_sim/ivci_2_axi/p_vci_in.plen {-height 17 -radix decimal}} /axi_vci_sim/ivci_2_axi/p_vci_in
add wave -noupdate /axi_vci_sim/ivci_2_axi/p_vci_out
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_addr
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_len
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_burst
add wave -noupdate /axi_vci_sim/ivci_2_axi/r_srcid
add wave -noupdate -divider axi_ram
add wave -noupdate /axi_vci_sim/iaxi_ram/r_state
add wave -noupdate /axi_vci_sim/iaxi_ram/p_axi_in
add wave -noupdate /axi_vci_sim/iaxi_ram/p_axi_out
add wave -noupdate /axi_vci_sim/iaxi_ram/r_words
add wave -noupdate /axi_vci_sim/iaxi_ram/r_cnt
add wave -noupdate /axi_vci_sim/iaxi_ram/r_addr
add wave -noupdate /axi_vci_sim/iaxi_ram/r_srcid
add wave -noupdate /axi_vci_sim/iaxi_ram/s_data_in
add wave -noupdate /axi_vci_sim/iaxi_ram/s_data_out
add wave -noupdate /axi_vci_sim/iaxi_ram/s_be_in
add wave -noupdate /axi_vci_sim/iaxi_ram/s_eop
add wave -noupdate /axi_vci_sim/iaxi_ram/s_wen
add wave -noupdate -divider ram
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/clk
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/ce
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/addr
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/wdata
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/be
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/we
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/rdata
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/mem
add wave -noupdate /axi_vci_sim/iaxi_ram/iram/r_addr
TreeUpdate [SetDefaultTree]
WaveRestoreCursors {{Cursor 1} {0 ps} 0}
quietly wave cursor active 0
configure wave -namecolwidth 150
configure wave -valuecolwidth 100
configure wave -justifyvalue left
configure wave -signalnamewidth 0
configure wave -snapdistance 10
configure wave -datasetprefix 0
configure wave -rowmargin 4
configure wave -childrowmargin 2
configure wave -gridoffset 0
configure wave -gridperiod 1
configure wave -griddelta 40
configure wave -timeline 0
configure wave -timelineunits ps
update
WaveRestoreZoom {0 ps} {409 ps}
